Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( DefaultHover = 48 DefaultSelected = 96 )
Functions ¶
Types ¶
type Palette ¶ added in v0.0.2
type Palette struct {
// Bg is the background color atop which content is currently being
// drawn.
Bg color.NRGBA
// Fg is a color suitable for drawing on top of Bg.
Fg color.NRGBA
// ContrastBg is a color used to draw attention to active,
// important, interactive widgets such as buttons.
ContrastBg color.NRGBA
// ContrastFg is a color suitable for content drawn on top of
// ContrastBg.
ContrastFg color.NRGBA
// Bg2 specifies the background color for components like navibar
Bg2 color.NRGBA
HoverAlpha, SelectedAlpha uint8
}
type SubThemeID ¶ added in v0.0.2
type SubThemeID string
type Theme ¶
type Theme struct {
*material.Theme
// Alpha is the set of alpha values to be applied for certain
// states like hover, selected, etc...
HoverAlpha, SelectedAlpha uint8
// Bg2 specifies the background color for components like navibar
Bg2 color.NRGBA
// contains filtered or unexported fields
}
func (*Theme) Get ¶ added in v0.0.2
func (th *Theme) Get(ID SubThemeID) interface{}
func (*Theme) Register ¶ added in v0.0.2
func (th *Theme) Register(ID SubThemeID, sub interface{}) error
func (*Theme) WithPalette ¶ added in v0.0.2
Click to show internal directories.
Click to hide internal directories.